clear all
set more off

global svfoldp "ADDPATH\"
global svfoldpOUT "ADDPATH\outregs\"
global svfoldpDO "ADDPATH\do_files\"
global svfoldpWF "ADDPATH\workfiles\"
global svfoldpFIG "ADDPATH\figures\"

cd "${svfoldpWF}"


use step003_merged_data, clear


use step003_merged_data, clear

gen wgt_wave=1

gen egdp_std_bt2=egdp_std_bt^2
gen egdp_std_pt2=egdp_std_pt^2
	
gen epi_std_pt2=epi_std_pt^2
gen epi_std_bt2=epi_std_bt^2
gen w2_epi_std_pt2=w2_epi_std_pt^2

gen esales_std_bt2=esales_std_bt^2
gen esales_std_pt2=esales_std_pt^2
gen w2_esales_std_pt2=w2_esales_std_pt^2

	
***=============================================================================
***				GDP: mean
***=============================================================================
	capture drop preM
	gen preM=egdp_mean_bt
	capture drop postM
	gen postM=egdp_mean_pt


	*** binscatter plot for treatment and control groups
	*** posterior vs prior
	local bins0=20
	quiet forvalues var2=1(1)4 {
		xtile c_`var2'=preM   if treatmentN==`var2', nq(`bins0')
		egen x_`var2'=mean(preM ) if  treatmentN==`var2', by(c_`var2')
		egen y_`var2'=mean(postM ) if  treatmentN==`var2', by(c_`var2')
		egen w_`var2'=mean(wgt_wave) if treatmentN==`var2', by(c_`var2')
		replace x_`var2'=x_`var2'/ w_`var2'
		replace y_`var2'=y_`var2'/ w_`var2'	
	}

		xtile c_00=preM , nq(`bins0')
		egen x_00=mean(preM) , by(c_00)

	forvalues var2=1(1)4 {
		sort  x_`var2'
		by x_`var2': gen _t_`var2'=_n
	}
		
		sort  x_00
		by x_00: gen _t_00=_n

replace preM=-0.5 if preM<-0.5 & preM~=.
replace preM=7.5 if preM>7.5 & preM~=.
replace postM=-0.5 if postM<-0.5 & postM~=.
replace postM=7.5 if postM>7.5 & postM~=.

		
twoway ///
		/// TREATMENT GROUP
		(lfit postM preM    if treatmentN==4  , lcolor(gs8) lpattern(solid) lwidth(thick)) ///			
		(scatter y_4 x_4 if _t_4==1, msymbol(d) mcolor(black) mfcolor(white)) ///
		/// CONTROL GROUP
		(lfit postM preM   if treatmentN==1  , lcolor(black)) ///		
		(scatter y_1 x_1 if _t_1==1, msymbol(o) mfcolor(white) mcolor(black)) ///
		/// TREATMENT GROUP
		(lfit postM preM    if treatmentN==2  , lcolor(black) lpattern(shortdash)) ///		
		(scatter y_2 x_2 if _t_2==1, msymbol(t) mfcolor(white) mcolor(black) ) ///
		/// TREATMENT GROUP
		(lfit postM preM    if treatmentN==3  , lcolor(black) lpattern(longdash)) ///		
		(scatter y_3 x_3 if _t_3==1, msymbol(s) mfcolor(white) mcolor(black) ) ///
		, ///
		legend(off) ///
		xtitle("Prior GDP: mean") xlabel(0(1)7) ///
		ytitle("Posterior GDP: mean") ylabel(0(1)7) ///
		title("Panel A: GDP (mean)", size(med)) ///
		graphregion(color(white)) bgcolor(white) ///
		name(fig1A, replace)

		
twoway ///
		/// TREATMENT GROUP
		(lfit postM preM    if treatmentN==4  , lcolor(red) lpattern(solid) lwidth(thick)) ///			
		(scatter y_4 x_4 if _t_4==1, msymbol(d) mcolor(red) mfcolor(white)) ///
		/// CONTROL GROUP
		(lfit postM preM   if treatmentN==1  , lcolor(black)) ///		
		(scatter y_1 x_1 if _t_1==1, msymbol(o) mfcolor(white) mcolor(black)) ///
		/// TREATMENT GROUP
		(lfit postM preM    if treatmentN==2  , lcolor(blue) lpattern(shortdash)) ///		
		(scatter y_2 x_2 if _t_2==1, msymbol(t) mfcolor(white) mcolor(blue) ) ///
		/// TREATMENT GROUP
		(lfit postM preM    if treatmentN==3  , lcolor(green) lpattern(longdash)) ///		
		(scatter y_3 x_3 if _t_3==1, msymbol(s) mfcolor(white) mcolor(green) ) ///
		, ///
		legend(off) ///
		xtitle("Prior GDP: mean") xlabel(0(1)7) ///
		ytitle("Posterior GDP: mean") ylabel(0(1)7) ///
		title("Panel A: GDP (mean)", size(med)) ///
		graphregion(color(white)) bgcolor(white) ///
		name(fig1A_color, replace)

		
		

***=============================================================================
***				GDP: uncertainty
***=============================================================================
 

	capture drop preM
	gen preM=egdp_range_bt
	capture drop postM
	gen postM=egdp_range_pt

	capture drop c_* 
	capture drop x_* 
	capture drop  y_*
	capture drop w_* 
	capture drop _t_*
	
	*** binscatter plot for treatment and control groups
	*** posterior vs prior
	local bins0=20
	quiet forvalues var2=1(1)4 {
		xtile c_`var2'=preM   if treatmentN==`var2', nq(`bins0')
		egen x_`var2'=mean(preM ) if  treatmentN==`var2', by(c_`var2')
		egen y_`var2'=mean(postM ) if  treatmentN==`var2', by(c_`var2')
		egen w_`var2'=mean(wgt_wave) if treatmentN==`var2', by(c_`var2')
		replace x_`var2'=x_`var2'/ w_`var2'
		replace y_`var2'=y_`var2'/ w_`var2'	
	}

		xtile c_00=preM , nq(`bins0')
		egen x_00=mean(preM) , by(c_00)

	forvalues var2=1(1)4 {
		sort  x_`var2'
		by x_`var2': gen _t_`var2'=_n
	}
		
		sort  x_00
		by x_00: gen _t_00=_n


twoway ///
		/// TREATMENT GROUP
		(lfit postM preM    if treatmentN==4  , lcolor(gs8) lpattern(solid) lwidth(thick)) ///			
		(scatter y_4 x_4 if _t_4==1, msymbol(d) mcolor(black) mfcolor(white)) ///
		/// CONTROL GROUP
		(lfit postM preM   if treatmentN==1  , lcolor(black)) ///		
		(scatter y_1 x_1 if _t_1==1, msymbol(o) mfcolor(white) mcolor(black)) ///
		/// TREATMENT GROUP
		(lfit postM preM    if treatmentN==2  , lcolor(black) lpattern(shortdash)) ///		
		(scatter y_2 x_2 if _t_2==1, msymbol(t) mfcolor(white) mcolor(black) ) ///
		/// TREATMENT GROUP
		(lfit postM preM    if treatmentN==3  , lcolor(black) lpattern(longdash)) ///		
		(scatter y_3 x_3 if _t_3==1, msymbol(s) mfcolor(white) mcolor(black) ) ///
		, ///
		legend(off) ///
		xtitle("Prior GDP: uncertainty")  ///
		ytitle("Posterior GDP: uncertainty") ///
		title("Panel B: GDP (uncertainty)", size(med)) ///	
		graphregion(color(white)) bgcolor(white) ///
		name(fig1B, replace) 

		
twoway ///
		/// TREATMENT GROUP
		(lfit postM preM    if treatmentN==4  , lcolor(red) lpattern(solid) lwidth(thick)) ///			
		(scatter y_4 x_4 if _t_4==1, msymbol(d) mcolor(red) mfcolor(white)) ///
		/// CONTROL GROUP
		(lfit postM preM   if treatmentN==1  , lcolor(black)) ///		
		(scatter y_1 x_1 if _t_1==1, msymbol(o) mfcolor(white) mcolor(black)) ///
		/// TREATMENT GROUP
		(lfit postM preM    if treatmentN==2  , lcolor(blue) lpattern(shortdash)) ///		
		(scatter y_2 x_2 if _t_2==1, msymbol(t) mfcolor(white) mcolor(blue) ) ///
		/// TREATMENT GROUP
		(lfit postM preM    if treatmentN==3  , lcolor(green) lpattern(longdash)) ///		
		(scatter y_3 x_3 if _t_3==1, msymbol(s) mfcolor(white) mcolor(green) ) ///
		, ///
		legend(off) ///
		xtitle("Prior GDP: uncertainty")  ///
		ytitle("Posterior GDP: uncertainty") ///
		title("Panel B: GDP (uncertainty)", size(med)) ///	
		graphregion(color(white)) bgcolor(white) ///
		name(fig1B_color, replace) 
		

***=============================================================================
***				Inflation: mean
***=============================================================================
 

	capture drop preM
	gen preM=epi_mean_bt
	capture drop postM
	gen postM=epi_mean_pt

	capture drop c_* 
	capture drop x_* 
	capture drop  y_*
	capture drop w_* 
	capture drop _t_*
	
	*** binscatter plot for treatment and control groups
	*** posterior vs prior
	local bins0=20
	quiet forvalues var2=1(1)4 {
		xtile c_`var2'=preM   if treatmentN==`var2', nq(`bins0')
		egen x_`var2'=mean(preM ) if  treatmentN==`var2', by(c_`var2')
		egen y_`var2'=mean(postM ) if  treatmentN==`var2', by(c_`var2')
		egen w_`var2'=mean(wgt_wave) if treatmentN==`var2', by(c_`var2')
		replace x_`var2'=x_`var2'/ w_`var2'
		replace y_`var2'=y_`var2'/ w_`var2'	
	}

		xtile c_00=preM , nq(`bins0')
		egen x_00=mean(preM) , by(c_00)

	forvalues var2=1(1)4 {
		sort  x_`var2'
		by x_`var2': gen _t_`var2'=_n
	}
		
		sort  x_00
		by x_00: gen _t_00=_n

replace preM=1.5 if preM<1.5 & preM~=.
replace preM=8.5 if preM>8.5 & preM~=.
replace postM=1.5 if postM<1.5 & postM~=.
replace postM=8.5 if postM>8.5 & postM~=.


twoway ///
		/// TREATMENT GROUP
		(lfit postM preM    if treatmentN==4  , lcolor(gs8) lpattern(solid) lwidth(thick)) ///			
		(scatter y_4 x_4 if _t_4==1, msymbol(d) mcolor(black) mfcolor(white)) ///
		/// CONTROL GROUP
		(lfit postM preM   if treatmentN==1  , lcolor(black)) ///		
		(scatter y_1 x_1 if _t_1==1, msymbol(o) mfcolor(white) mcolor(black)) ///
		/// TREATMENT GROUP
		(lfit postM preM    if treatmentN==2  , lcolor(black) lpattern(shortdash)) ///		
		(scatter y_2 x_2 if _t_2==1, msymbol(t) mfcolor(white) mcolor(black) ) ///
		/// TREATMENT GROUP
		(lfit postM preM    if treatmentN==3  , lcolor(black) lpattern(longdash)) ///		
		(scatter y_3 x_3 if _t_3==1, msymbol(s) mfcolor(white) mcolor(black) ) ///
		, ///
		legend(off) ///
		xtitle("Prior inflation: mean") xlabel(2(1)8) ///
		ytitle("Posterior inflation: mean") ylabel(2(1)8) ///
		title("Panel C: Inflation (mean)", size(med)) ///	
		graphregion(color(white)) bgcolor(white) ///
		name(fig2A, replace) 
		
twoway ///
		/// TREATMENT GROUP
		(lfit postM preM    if treatmentN==4  , lcolor(red) lpattern(solid) lwidth(thick)) ///			
		(scatter y_4 x_4 if _t_4==1, msymbol(d) mcolor(red) mfcolor(white)) ///
		/// CONTROL GROUP
		(lfit postM preM   if treatmentN==1  , lcolor(black)) ///		
		(scatter y_1 x_1 if _t_1==1, msymbol(o) mfcolor(white) mcolor(black)) ///
		/// TREATMENT GROUP
		(lfit postM preM    if treatmentN==2  , lcolor(blue) lpattern(shortdash)) ///		
		(scatter y_2 x_2 if _t_2==1, msymbol(t) mfcolor(white) mcolor(blue) ) ///
		/// TREATMENT GROUP
		(lfit postM preM    if treatmentN==3  , lcolor(green) lpattern(longdash)) ///		
		(scatter y_3 x_3 if _t_3==1, msymbol(s) mfcolor(white) mcolor(green) ) ///
		, ///
		legend(off) ///
		xtitle("Prior inflation: mean") xlabel(2(1)8) ///
		ytitle("Posterior inflation: mean") ylabel(2(1)8) ///
		title("Panel C: Inflation (mean)", size(med)) ///	
		graphregion(color(white)) bgcolor(white) ///
		name(fig2A_color, replace) 
		
		
		
***=============================================================================
***				Inflation: uncertainty
***=============================================================================
  

	capture drop preM
	gen preM=epi_range_bt
	capture drop postM
	gen postM=epi_range_pt

	capture drop c_* 
	capture drop x_* 
	capture drop  y_*
	capture drop w_* 
	capture drop _t_*
	
	*** binscatter plot for treatment and control groups
	*** posterior vs prior
	local bins0=20
	quiet forvalues var2=1(1)4 {
		xtile c_`var2'=preM   if treatmentN==`var2', nq(`bins0')
		egen x_`var2'=mean(preM ) if  treatmentN==`var2', by(c_`var2')
		egen y_`var2'=mean(postM ) if  treatmentN==`var2', by(c_`var2')
		egen w_`var2'=mean(wgt_wave) if treatmentN==`var2', by(c_`var2')
		replace x_`var2'=x_`var2'/ w_`var2'
		replace y_`var2'=y_`var2'/ w_`var2'	
	}

		xtile c_00=preM , nq(`bins0')
		egen x_00=mean(preM) , by(c_00)

	forvalues var2=1(1)4 {
		sort  x_`var2'
		by x_`var2': gen _t_`var2'=_n
	}
		
		sort  x_00
		by x_00: gen _t_00=_n


twoway ///
		/// TREATMENT GROUP
		(lfit postM preM    if treatmentN==4  , lcolor(gs8) lpattern(solid) lwidth(thick)) ///			
		(scatter y_4 x_4 if _t_4==1, msymbol(d) mcolor(black) mfcolor(white)) ///
		/// CONTROL GROUP
		(lfit postM preM   if treatmentN==1  , lcolor(black)) ///		
		(scatter y_1 x_1 if _t_1==1, msymbol(o) mfcolor(white) mcolor(black)) ///
		/// TREATMENT GROUP
		(lfit postM preM    if treatmentN==2  , lcolor(black) lpattern(shortdash)) ///		
		(scatter y_2 x_2 if _t_2==1, msymbol(t) mfcolor(white) mcolor(black) ) ///
		/// TREATMENT GROUP
		(lfit postM preM    if treatmentN==3  , lcolor(black) lpattern(longdash)) ///		
		(scatter y_3 x_3 if _t_3==1, msymbol(s) mfcolor(white) mcolor(black) ) ///
		, ///
		legend(off) ///
		xtitle("Prior inflation: uncertainty")  ///
		ytitle("Posterior inflation: uncertainty") ///
		title("Panel D: Inflation (uncertainty)", size(med)) ///
		graphregion(color(white)) bgcolor(white) ///
		name(fig2B, replace) 				
		

twoway ///
		/// TREATMENT GROUP
		(lfit postM preM    if treatmentN==4  , lcolor(red) lpattern(solid) lwidth(thick)) ///			
		(scatter y_4 x_4 if _t_4==1, msymbol(d) mcolor(red) mfcolor(white)) ///
		/// CONTROL GROUP
		(lfit postM preM   if treatmentN==1  , lcolor(black)) ///		
		(scatter y_1 x_1 if _t_1==1, msymbol(o) mfcolor(white) mcolor(black)) ///
		/// TREATMENT GROUP
		(lfit postM preM    if treatmentN==2  , lcolor(blue) lpattern(shortdash)) ///		
		(scatter y_2 x_2 if _t_2==1, msymbol(t) mfcolor(white) mcolor(blue) ) ///
		/// TREATMENT GROUP
		(lfit postM preM    if treatmentN==3  , lcolor(green) lpattern(longdash)) ///		
		(scatter y_3 x_3 if _t_3==1, msymbol(s) mfcolor(white) mcolor(green) ) ///
		, ///
		legend(off) ///
		xtitle("Prior inflation: uncertainty")  ///
		ytitle("Posterior inflation: uncertainty") ///
		title("Panel D: Inflation (uncertainty)", size(med)) ///
		graphregion(color(white)) bgcolor(white) ///
		name(fig2B_color, replace) 				
				
	
***=============================================================================
***				Sales: mean
***=============================================================================
  
 
	capture drop preM
	gen preM=esales_mean_bt
	capture drop postM
	gen postM=esales_mean_pt

	capture drop c_* 
	capture drop x_* 
	capture drop  y_*
	capture drop w_* 
	capture drop _t_*
	
	*** binscatter plot for treatment and control groups
	*** posterior vs prior
	local bins0=20
	quiet forvalues var2=1(1)4 {
		xtile c_`var2'=preM   if treatmentN==`var2', nq(`bins0')
		egen x_`var2'=mean(preM ) if  treatmentN==`var2', by(c_`var2')
		egen y_`var2'=mean(postM ) if  treatmentN==`var2', by(c_`var2')
		egen w_`var2'=mean(wgt_wave) if treatmentN==`var2', by(c_`var2')
		replace x_`var2'=x_`var2'/ w_`var2'
		replace y_`var2'=y_`var2'/ w_`var2'	
	}

		xtile c_00=preM , nq(`bins0')
		egen x_00=mean(preM) , by(c_00)

	forvalues var2=1(1)4 {
		sort  x_`var2'
		by x_`var2': gen _t_`var2'=_n
	}
		
		sort  x_00
		by x_00: gen _t_00=_n

replace preM=-3.5 if preM<-3.5 & preM~=.
replace preM=7.5 if preM>7.5 & preM~=.
replace postM=-3.5 if postM<-3.5 & postM~=.
replace postM=7.5 if postM>7.5 & postM~=.



reg y_4 x_4 if _t_4==1 
predict y_4_hat if e(sample), xb
reg y_1 x_1 if _t_1==1 
predict y_1_hat if e(sample), xb
reg y_2 x_2 if _t_2==1
predict y_2_hat if e(sample), xb
reg y_3 x_3 if _t_3==1
predict y_3_hat if e(sample), xb


twoway ///
		/// TREATMENT GROUP
		(scatter y_4_hat x_4 if _t_4==1, msymbol(d) mcolor(black) mfcolor(white) lcolor(gs8) lpattern(solid) lwidth(thick) connect(direct)) ///
		(lfit postM preM    if treatmentN==4  , lcolor(gs8) lpattern(solid) lwidth(thick)) ///			
		(scatter y_4 x_4 if _t_4==1, msymbol(d) mcolor(black) mfcolor(white)) ///
		/// CONTROL GROUP
		(scatter  y_1_hat x_1 if _t_1==1, lcolor(black) msymbol(o) mfcolor(white) mcolor(black)  connect(direct)) ///
		(lfit postM preM   if treatmentN==1  , lcolor(black)) ///		
		(scatter y_1 x_1 if _t_1==1, msymbol(o) mfcolor(white) mcolor(black)) ///
		/// TREATMENT GROUP
		(scatter y_2_hat x_2 if _t_2==1,  msymbol(t) mfcolor(white) mcolor(black) lcolor(black) lpattern(shortdash) connect(direct)) ///
		(lfit postM preM    if treatmentN==2  , lcolor(black) lpattern(shortdash)) ///		
		(scatter y_2 x_2 if _t_2==1, msymbol(t) mfcolor(white) mcolor(black) ) ///
		/// TREATMENT GROUP
		(scatter y_3_hat x_3 if _t_3==1 , lcolor(black) lpattern(longdash) msymbol(s) mfcolor(white) mcolor(black) connect(direct) ) ///
		(lfit postM preM    if treatmentN==3  , lcolor(black) lpattern(longdash)) ///		
		(scatter y_3 x_3 if _t_3==1, msymbol(s) mfcolor(white) mcolor(black) ) ///
		, ///
		legend(order( 4 7 10 1)  ///
			label(4 "Control") ///
			label(7 "Mean treatment") ///
			label(10 "Uncertainty treatment") ///
			label(1 "Mean & Uncert. treatment") ///
			ring(0) position(5) rows(4) size(vsmall) rowgap(0.1) symysize(*0.5) symxsize(*0.8)) ///
		xtitle("Prior sales: mean") xlabel(-3(1)7) ///
		ytitle("Posterior sales: mean") ylabel(-3(1)7) ///
		title("Panel E: Sales growth (mean)", size(med)) ///	
		graphregion(color(white)) bgcolor(white) ///
		name(fig3A, replace) 				
		

twoway ///
		/// TREATMENT GROUP
		(scatter y_4_hat x_4 if _t_4==1, msymbol(d) mcolor(red) mfcolor(white) lcolor(red) lpattern(solid) lwidth(thick) connect(direct)) ///
		(lfit postM preM    if treatmentN==4  , lcolor(red) lpattern(solid) lwidth(thick)) ///			
		(scatter y_4 x_4 if _t_4==1, msymbol(d) mcolor(red) mfcolor(white)) ///
		/// CONTROL GROUP
		(scatter  y_1_hat x_1 if _t_1==1, lcolor(black) msymbol(o) mfcolor(white) mcolor(black)  connect(direct)) ///
		(lfit postM preM   if treatmentN==1  , lcolor(black)) ///		
		(scatter y_1 x_1 if _t_1==1, msymbol(o) mfcolor(white) mcolor(black)) ///
		/// TREATMENT GROUP
		(scatter y_2_hat x_2 if _t_2==1,  msymbol(t) mfcolor(white) mcolor(blue) lcolor(blue) lpattern(shortdash) connect(direct)) ///
		(lfit postM preM    if treatmentN==2  , lcolor(blue) lpattern(shortdash)) ///		
		(scatter y_2 x_2 if _t_2==1, msymbol(t) mfcolor(white) mcolor(blue) ) ///
		/// TREATMENT GROUP
		(scatter y_3_hat x_3 if _t_3==1 , lcolor(green) lpattern(longdash) msymbol(s) mfcolor(white) mcolor(green) connect(direct) ) ///
		(lfit postM preM    if treatmentN==3  , lcolor(green) lpattern(longdash)) ///		
		(scatter y_3 x_3 if _t_3==1, msymbol(s) mfcolor(white) mcolor(green) ) ///
		, ///
		legend(order( 4 7 10 1)  ///
			label(4 "Control") ///
			label(7 "Mean treatment") ///
			label(10 "Uncertainty treatment") ///
			label(1 "Mean & Uncert. treatment") ///
			ring(0) position(5) rows(4) size(vsmall) rowgap(0.1) symysize(*0.5) symxsize(*0.8)) ///
		xtitle("Prior sales: mean") xlabel(-3(1)7) ///
		ytitle("Posterior sales: mean") ylabel(-3(1)7) ///
		title("Panel E: Sales growth (mean)", size(med)) ///	
		graphregion(color(white)) bgcolor(white) ///
		name(fig3A_color, replace) 				
		
		
		
	
***=============================================================================
***				Sales: uncertainty
***=============================================================================
  
  
	capture drop preM
	gen preM=esales_range_bt
	capture drop postM
	gen postM=esales_range_pt

	capture drop c_* 
	capture drop x_* 
	capture drop  y_*
	capture drop w_* 
	capture drop _t_*
	
	*** binscatter plot for treatment and control groups
	*** posterior vs prior
	local bins0=20
	quiet forvalues var2=1(1)4 {
		xtile c_`var2'=preM   if treatmentN==`var2', nq(`bins0')
		egen x_`var2'=mean(preM ) if  treatmentN==`var2', by(c_`var2')
		egen y_`var2'=mean(postM ) if  treatmentN==`var2', by(c_`var2')
		egen w_`var2'=mean(wgt_wave) if treatmentN==`var2', by(c_`var2')
		replace x_`var2'=x_`var2'/ w_`var2'
		replace y_`var2'=y_`var2'/ w_`var2'	
	}

		xtile c_00=preM , nq(`bins0')
		egen x_00=mean(preM) , by(c_00)

	forvalues var2=1(1)4 {
		sort  x_`var2'
		by x_`var2': gen _t_`var2'=_n
	}
		
		sort  x_00
		by x_00: gen _t_00=_n


twoway ///
		/// TREATMENT GROUP
		(lfit postM preM    if treatmentN==4 , lcolor(gs8) lpattern(solid) lwidth(thick)) ///			
		(scatter y_4 x_4 if _t_4==1, msymbol(d) mcolor(black) mfcolor(white) mfcolor(black)) ///
		/// CONTROL GROUP
		(lfit postM preM   if treatmentN==1 , lcolor(black)) ///		
		(scatter y_1 x_1 if _t_1==1, msymbol(o) mfcolor(white) mcolor(black)) ///
		/// TREATMENT GROUP
		(lfit postM preM    if treatmentN==2 , lcolor(black) lpattern(shortdash)) ///		
		(scatter y_2 x_2 if _t_2==1, msymbol(t) mfcolor(white) mcolor(black) ) ///
		/// TREATMENT GROUP
		(lfit postM preM    if treatmentN==3 , lcolor(black) lpattern(longdash)) ///		
		(scatter y_3 x_3 if _t_3==1, msymbol(s) mfcolor(white) mcolor(black) ) ///
		, ///
		legend(off) ///
		xtitle("Prior sales: uncertainty")  ///
		ytitle("Posterior sales: uncertainty") ///
		title("Panel F: Sales growth (uncertainty)", size(med)) ///	
		graphregion(color(white)) bgcolor(white) ///
		name(fig3B, replace) 				
		

twoway ///
		/// TREATMENT GROUP
		(lfit postM preM    if treatmentN==4 , lcolor(red) lpattern(solid) lwidth(thick)) ///			
		(scatter y_4 x_4 if _t_4==1, msymbol(d) mcolor(black) mfcolor(white) mfcolor(red)) ///
		/// CONTROL GROUP
		(lfit postM preM   if treatmentN==1 , lcolor(black)) ///		
		(scatter y_1 x_1 if _t_1==1, msymbol(o) mfcolor(white) mcolor(black)) ///
		/// TREATMENT GROUP
		(lfit postM preM    if treatmentN==2 , lcolor(blue) lpattern(shortdash)) ///		
		(scatter y_2 x_2 if _t_2==1, msymbol(t) mfcolor(white) mcolor(blue) ) ///
		/// TREATMENT GROUP
		(lfit postM preM    if treatmentN==3 , lcolor(green) lpattern(longdash)) ///		
		(scatter y_3 x_3 if _t_3==1, msymbol(s) mfcolor(white) mcolor(green) ) ///
		, ///
		legend(off) ///
		xtitle("Prior sales: uncertainty")  ///
		ytitle("Posterior sales: uncertainty") ///
		title("Panel F: Sales growth (uncertainty)", size(med)) ///	
		graphregion(color(white)) bgcolor(white) ///
		name(fig3B_color, replace) 	
		
		
				
***============================================================================
cd "${svfoldpFIG}"
	
graph combine fig1A fig1B  fig2A fig2B fig3A fig3B , ///
	rows(3) xsize(24) ysize(32) imargin(tiny) ///
	graphregion(color(white))  ///
	name(fig13_combine, replace)

graph export figure04.eps, replace
graph export figure04.pdf, replace
graph export figure04.emf, replace
graph export figure04.tif, replace

	
graph combine fig1A_color fig1B_color  fig2A_color fig2B_color fig3A_color fig3B_color , ///
	rows(3) xsize(24) ysize(32) imargin(tiny) ///
	graphregion(color(white))  ///
	name(fig13_combine_color, replace)	
	
graph export figure04_color.eps, replace
graph export figure04_color.pdf, replace
graph export figure04_color.emf, replace
graph export figure04_color.tif, replace
	