clear all
set more off

global svfoldp "ADDPATH\"
global svfoldpOUT "ADDPATH\outregs\"
global svfoldpDO "ADDPATH\do_files\"
global svfoldpWF "ADDPATH\workfiles\"
global svfoldpFIG "ADDPATH\figures\"

cd "${svfoldpWF}"

use step003_merged_data, clear

cd "${svfoldpOUT}"

*===============================================================================
*				2nd stage regressions for output
*				posteriors from immediately after the treatment
*				No controls
*===============================================================================

gen Z1=egdp_std_bt^2
gen Z2=(treatmentN==2)*egdp_std_bt^2 if treatmentN~=.
gen Z3=(treatmentN==3)*egdp_std_bt^2 if treatmentN~=.
gen Z4=(treatmentN==4)*egdp_std_bt^2 if treatmentN~=.

gen W1=egdp_mean_bt
gen W2=(treatmentN==2)*egdp_mean_bt if treatmentN~=.
gen W3=(treatmentN==3)*egdp_mean_bt if treatmentN~=.
gen W4=(treatmentN==4)*egdp_mean_bt if treatmentN~=.

gen X2=(treatmentN==2)  if treatmentN~=.
gen X3=(treatmentN==3)  if treatmentN~=.
gen X4=(treatmentN==4)  if treatmentN~=.

gen egdp_std_bt2=egdp_std_bt^2
gen egdp_std_pt2=egdp_std_pt^2



****============================================================================
****				heterogeneity
****============================================================================

****~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
**** 		create samples
****~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

*** industry
gen S1=Industry=="Manufacturing"
local txt1="Manufacturing"
gen S2=(Industry=="Professional and financial services") | (Industry=="Trade") | (Industry=="Transportation") 
local txt2="non-Manufacturing, excl. construction"


*** size (employment)
gen S3=(Q2A<10)  if Q2A~=. 
local txt3="# of workes<10"
gen S4=(Q2A>=10) & (Q2A<30)  if Q2A~=. 
local txt4="# of workes>=10 & workers<30"
gen S5=(Q2A>=30) if Q2A~=. 
local txt5="# of workes>=30"

*** number of competitors
gen S6=(BQ11C==0) if BQ11C~=.
local txt6="number of competitors =0"

gen S7=(BQ11C>0 & BQ11C<5) if BQ11C~=.
local txt7="number of competitors >0 & <5"

gen S8=(BQ11C>=5) if BQ11C~=.
local txt8="number of competitors >=5"


*** utilization
gen S9=(utilization<0.8) if utilization~=.
local txt9="utilization <0.8"

gen S10=(utilization>=0.8 & utilization<=1) if utilization~=.
local txt10="utilization >=0.8 & <=1"

gen S11=(utilization>1) if utilization~=.
local txt11="utilization >1"


*** value of macro information (forecast)
gen S12=(Q9<335) if Q9~=.
local txt12="value of macro forecats <$335"

gen S13=(Q9>=335) &(Q9<594) if Q9~=.
local txt13="value of macro forecats >=$335 & <$594"

gen S14=(Q9>=594) if Q9~=.
local txt14="value of macro forecats >=$594"


*** association 
gen S15=(BQ4==1) if BQ4~=.
local txt15="prof. assoc. member: many"

gen S16=(BQ4==2) if BQ4~=.
local txt16="prof. assoc. member: one"

gen S17=(BQ4==3) if BQ4~=.
local txt17="prof. assoc. member: no"

*** COVID
encode Subsector, gen(_Subsector)

/*
. label list _Subsector
_Subsector:
           1 Accounting services
           2 All other professional services
           3 Auxiliary finance and insurance
           4 Car, supermarket and food retailing
           5 Chemicals and metals
           6 Construction
           7 Equipment and machinery
           8 Finance
           9 Food and beverage
          10 Hotel and food services
          11 Insurance
          12 Legal services
          13 Other store retailing
          14 Paper, wood, printing and furniture
          15 Rental, hiring and real estate
          16 Textile and clothing
          17 Transportation
          18 Wholesale trade
*/

		  
*** expsoure to COVID
* low exposure
gen S18=(_Subsector==1) | (_Subsector==2) | (_Subsector==3) | (_Subsector==5) | (_Subsector==6) | (_Subsector==7)  | (_Subsector==8)  | (_Subsector==12) | (_Subsector==14) | (_Subsector==16)
local txt18="Low COVID exposure"
gen S19=(_Subsector==4) | (_Subsector==9) | (_Subsector==10) | (_Subsector==11) | (_Subsector==13) | (_Subsector==15) | (_Subsector==17) | (_Subsector==18)
local txt19="High COVID exposure"



foreach var in CQ8C CQ8D  CQ10 CQ11 CQ12 {
	tempname 1
	postfile `1'  str4 smpl ///
		str50 smplX ///
		str12 b1 ///
		str12 b2 ///
		str12 NN ///	
		str12 F1 ///
		str12 F2 ///
		using "Table08_`var'.dta", replace every(1)
	
    noisily di `var'
	capture drop PLAN
	gen PLAN = `var'
	capture drop DEPVAR
	gen DEPVAR=w2_`var'-PLAN

	forvalues i=1(1)19 {	
		xi: ivreg2 DEPVAR egdp_mean_bt egdp_std_bt2 (egdp_mean_pt egdp_std_pt2 = egdp_mean_bt egdp_std_bt2 Z2 Z3 Z4 X2 X3 X4 W2 W3 W4) if S`i'==1, ffirst robust
		matrix MM=e(first)
		local F1=MM[4,1]
		local F2=MM[4,2]
		
		local t1=_b[egdp_mean_pt]/_se[egdp_mean_pt]
		local t2=_b[egdp_std_pt2]/_se[egdp_std_pt2]
		
		local _b1=string(_b[egdp_mean_pt],"%3.2f")
		if abs(`t1')>1.65 local _b1=string(_b[egdp_mean_pt],"%3.2f") + "*"
		if abs(`t1')>1.95 local _b1=string(_b[egdp_mean_pt],"%3.2f") + "**"
		if abs(`t1')>2.58 local _b1=string(_b[egdp_mean_pt],"%3.2f") + "***"
		
		local _b2=string(_b[egdp_std_pt2],"%3.2f")
		if abs(`t2')>1.65 local _b2=string(_b[egdp_std_pt2],"%3.2f") + "*"
		if abs(`t2')>1.95 local _b2=string(_b[egdp_std_pt2],"%3.2f") + "**"
		if abs(`t2')>2.58 local _b2=string(_b[egdp_std_pt2],"%3.2f") + "***"	
		
		local _se1="(" + string(_se[egdp_mean_pt],"%3.2f") + ")"	
		local _se2="(" + string(_se[egdp_std_pt2],"%3.2f") + ")"
		
		local _NN=string(e(N),"%5.0f")
		local _F1=string(`F1',"%3.2f")
		local _F2=string(`F2',"%3.2f")
		
		post `1' ("S`i'") ("`txt`i''")	("`_b1'") ("`_b2'")  ("`_NN'") ("`_F1'") ("`_F2'")  
		post `1' (" ") (" ")	("`_se1'") ("`_se2'")  (" ") (" ") (" ")  

	}	
	
	postclose `1'
}




	
	
	