clear all
set more off

global svfoldp "ADDPATH\"
global svfoldpOUT "ADDPATH\outregs\"
global svfoldpDO "ADDPATH\do_files\"
global svfoldpWF "ADDPATH\workfiles\"
global svfoldpFIG "ADDPATH\figures\"

cd "${svfoldpWF}"

use step003_merged_data, clear

gen dL=log(w2_Q2A/Q2A)*100 /* employment */
gen dY=log(w2_Q4A/Q4A)*100 /* sales */

gen dP=w2_CQ8A-CQ8A /* price change relative to plan*/

gen dValInfo=w2_BQ12-BQ12 /* change in the value of information */

gen lnY=log(Q4A)*100
gen w2_lnY=log(w2_Q4A)*100

gen w2_utilization = w2_Q4A/w2_Q4B
replace w2_utilization=1.4 if w2_utilization>1.4 & w2_utilization~=.

gen share_mainY=Q4C/Q4A
gen w2_share_mainY=w2_Q4C/w2_Q4A

gen share_mainL=Q2B/Q2A
gen w2_share_mainL=w2_Q2B/w2_Q2A

cd "${svfoldpOUT}"


*===============================================================================
*				2nd stage regressions for output
*				posteriors from immediately after the treatment
*				No controls
*===============================================================================

gen Z1=egdp_std_bt^2
gen Z2=(treatmentN==2)*egdp_std_bt^2 if treatmentN~=.
gen Z3=(treatmentN==3)*egdp_std_bt^2 if treatmentN~=.
gen Z4=(treatmentN==4)*egdp_std_bt^2 if treatmentN~=.

gen W1=egdp_mean_bt
gen W2=(treatmentN==2)*egdp_mean_bt if treatmentN~=.
gen W3=(treatmentN==3)*egdp_mean_bt if treatmentN~=.
gen W4=(treatmentN==4)*egdp_mean_bt if treatmentN~=.

gen X2=(treatmentN==2)  if treatmentN~=.
gen X3=(treatmentN==3)  if treatmentN~=.
gen X4=(treatmentN==4)  if treatmentN~=.

gen egdp_std_bt2=egdp_std_bt^2
gen egdp_std_pt2=egdp_std_pt^2




foreach var in lnY  Q9 BQ12 BQ13A  CQ8A CQ8B CQ8C CQ8D  CQ10 CQ11 CQ12 utilization share_mainY  share_mainL Q7A Q7B Q7C {
	gen DV_`var'=w2_`var'-`var'
}
	
rwolf2 (ivreg2 DV_CQ8A egdp_mean_bt egdp_std_bt2 (egdp_mean_pt egdp_std_pt2 = egdp_mean_bt egdp_std_bt2 Z2 Z3 Z4 X2 X3 X4 W2 W3 W4), ffirst robust) ///
		(ivreg2 DV_CQ8B egdp_mean_bt egdp_std_bt2 (egdp_mean_pt egdp_std_pt2 = egdp_mean_bt egdp_std_bt2 Z2 Z3 Z4 X2 X3 X4 W2 W3 W4), ffirst robust) ///
		(ivreg2 DV_CQ8C egdp_mean_bt egdp_std_bt2 (egdp_mean_pt egdp_std_pt2 = egdp_mean_bt egdp_std_bt2 Z2 Z3 Z4 X2 X3 X4 W2 W3 W4), ffirst robust) ///
		(ivreg2 DV_CQ8D egdp_mean_bt egdp_std_bt2 (egdp_mean_pt egdp_std_pt2 = egdp_mean_bt egdp_std_bt2 Z2 Z3 Z4 X2 X3 X4 W2 W3 W4), ffirst robust) ///
		///
		(ivreg2 DV_CQ10 egdp_mean_bt egdp_std_bt2 (egdp_mean_pt egdp_std_pt2 = egdp_mean_bt egdp_std_bt2 Z2 Z3 Z4 X2 X3 X4 W2 W3 W4), ffirst robust) ///
		(ivreg2 DV_CQ11 egdp_mean_bt egdp_std_bt2 (egdp_mean_pt egdp_std_pt2 = egdp_mean_bt egdp_std_bt2 Z2 Z3 Z4 X2 X3 X4 W2 W3 W4), ffirst robust) ///
		(ivreg2 DV_CQ12 egdp_mean_bt egdp_std_bt2 (egdp_mean_pt egdp_std_pt2 = egdp_mean_bt egdp_std_bt2 Z2 Z3 Z4 X2 X3 X4 W2 W3 W4), ffirst robust) ///
		, ///
		indepvars(egdp_mean_pt egdp_std_pt2, ///
				  egdp_mean_pt egdp_std_pt2, ///
				  egdp_mean_pt egdp_std_pt2, ///
				  egdp_mean_pt egdp_std_pt2, ///
				  ///
				  egdp_mean_pt egdp_std_pt2, ///
				  egdp_mean_pt egdp_std_pt2, ///
				  egdp_mean_pt egdp_std_pt2) ///
		seed(1234567) reps(100) ///
		graph
	
	
rwolf2 (ivreg2 DV_CQ8A egdp_mean_bt egdp_std_bt2 (egdp_mean_pt egdp_std_pt2 = egdp_mean_bt egdp_std_bt2 Z2 Z3 Z4 X2 X3 X4 W2 W3 W4), ffirst robust) ///
		(ivreg2 DV_CQ8B egdp_mean_bt egdp_std_bt2 (egdp_mean_pt egdp_std_pt2 = egdp_mean_bt egdp_std_bt2 Z2 Z3 Z4 X2 X3 X4 W2 W3 W4), ffirst robust) ///
		(ivreg2 DV_CQ8C egdp_mean_bt egdp_std_bt2 (egdp_mean_pt egdp_std_pt2 = egdp_mean_bt egdp_std_bt2 Z2 Z3 Z4 X2 X3 X4 W2 W3 W4), ffirst robust) ///
		(ivreg2 DV_CQ8D egdp_mean_bt egdp_std_bt2 (egdp_mean_pt egdp_std_pt2 = egdp_mean_bt egdp_std_bt2 Z2 Z3 Z4 X2 X3 X4 W2 W3 W4), ffirst robust) ///
		///
		(ivreg2 DV_CQ10 egdp_mean_bt egdp_std_bt2 (egdp_mean_pt egdp_std_pt2 = egdp_mean_bt egdp_std_bt2 Z2 Z3 Z4 X2 X3 X4 W2 W3 W4), ffirst robust) ///
		(ivreg2 DV_CQ11 egdp_mean_bt egdp_std_bt2 (egdp_mean_pt egdp_std_pt2 = egdp_mean_bt egdp_std_bt2 Z2 Z3 Z4 X2 X3 X4 W2 W3 W4), ffirst robust) ///
		(ivreg2 DV_CQ12 egdp_mean_bt egdp_std_bt2 (egdp_mean_pt egdp_std_pt2 = egdp_mean_bt egdp_std_bt2 Z2 Z3 Z4 X2 X3 X4 W2 W3 W4), ffirst robust) ///
		///
		(ivreg2 dL egdp_mean_bt egdp_std_bt2 (egdp_mean_pt egdp_std_pt2 = egdp_mean_bt egdp_std_bt2 Z2 Z3 Z4 X2 X3 X4 W2 W3 W4), ffirst robust) ///
		(ivreg2 DV_lnY egdp_mean_bt egdp_std_bt2 (egdp_mean_pt egdp_std_pt2 = egdp_mean_bt egdp_std_bt2 Z2 Z3 Z4 X2 X3 X4 W2 W3 W4), ffirst robust) ///
		(ivreg2 DV_Q9 egdp_mean_bt egdp_std_bt2 (egdp_mean_pt egdp_std_pt2 = egdp_mean_bt egdp_std_bt2 Z2 Z3 Z4 X2 X3 X4 W2 W3 W4), ffirst robust) ///
		(ivreg2 DV_BQ12 egdp_mean_bt egdp_std_bt2 (egdp_mean_pt egdp_std_pt2 = egdp_mean_bt egdp_std_bt2 Z2 Z3 Z4 X2 X3 X4 W2 W3 W4), ffirst robust) ///
		(ivreg2 DV_BQ13A egdp_mean_bt egdp_std_bt2 (egdp_mean_pt egdp_std_pt2 = egdp_mean_bt egdp_std_bt2 Z2 Z3 Z4 X2 X3 X4 W2 W3 W4), ffirst robust) ///
		///
		(ivreg2 w2_CQ9A CQ9A egdp_mean_bt egdp_std_bt2 (egdp_mean_pt egdp_std_pt2 = egdp_mean_bt egdp_std_bt2 Z2 Z3 Z4 X2 X3 X4 W2 W3 W4), ffirst robust) ///
		(ivreg2 w2_CQ9C CQ9C egdp_mean_bt egdp_std_bt2 (egdp_mean_pt egdp_std_pt2 = egdp_mean_bt egdp_std_bt2 Z2 Z3 Z4 X2 X3 X4 W2 W3 W4), ffirst robust) ///
		(ivreg2 w2_CQ9D CQ9D egdp_mean_bt egdp_std_bt2 (egdp_mean_pt egdp_std_pt2 = egdp_mean_bt egdp_std_bt2 Z2 Z3 Z4 X2 X3 X4 W2 W3 W4), ffirst robust) ///
		, ///
		indepvars(egdp_mean_pt egdp_std_pt2, ///
				  egdp_mean_pt egdp_std_pt2, ///
				  egdp_mean_pt egdp_std_pt2, ///
				  egdp_mean_pt egdp_std_pt2, ///
				  ///
				  egdp_mean_pt egdp_std_pt2, ///
				  egdp_mean_pt egdp_std_pt2, ///
				  egdp_mean_pt egdp_std_pt2, ///
				  ///
				  egdp_mean_pt egdp_std_pt2, ///
				  egdp_mean_pt egdp_std_pt2, ///
				  egdp_mean_pt egdp_std_pt2, ///
				  egdp_mean_pt egdp_std_pt2, ///
				  egdp_mean_pt egdp_std_pt2, ///
				  ///
				  egdp_mean_pt egdp_std_pt2, ///
				  egdp_mean_pt egdp_std_pt2, ///
				  egdp_mean_pt egdp_std_pt2) ///
		seed(1234567) reps(1000) ///
		graph
		
		
		
		
	matrix A=e(RW)	
