clear all
set more off

global svfoldp "ADDPATH\"
global svfoldpOUT "ADDPATH\outregs\"
global svfoldpDO "ADDPATH\do_files\"
global svfoldpWF "ADDPATH\workfiles\"
global svfoldpFIG "ADDPATH\figures\"

cd "${svfoldpWF}"

use step003_merged_data, clear

keep if treatmentN==1

*** binscatter plot for treatment and control groups
*** posterior vs prior
local bins0=20
gen _wgt=1

***~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*** 			prices
***~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
quiet forvalues grp=1(1)1 {
	xtile c1_`grp'=CQ8A [aw=_wgt] if treatmentN==`grp', nq(`bins0')
	egen x1_`grp'=mean(CQ8A) if treatmentN==`grp', by(c1_`grp')
	egen y1_`grp'=mean(w2_CQ8A) if  treatmentN==`grp', by(c1_`grp')
}

	xtile c1_00=CQ8A, nq(`bins0')
	egen x1_00=mean(CQ8A) , by(c1_00)

forvalues grp=1(1)1 {
	sort  x1_`grp'
	by x1_`grp': gen _t1_`grp'=_n
}
	
	sort  x1_00
	by x1_00: gen _t1_00=_n

***~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*** 			employment
***~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
quiet forvalues grp=1(1)1 {
	xtile c2_`grp'=CQ8B [aw=_wgt] if treatmentN==`grp', nq(`bins0')
	egen x2_`grp'=mean(CQ8B) if treatmentN==`grp', by(c2_`grp')
	egen y2_`grp'=mean(w2_CQ8B) if  treatmentN==`grp', by(c2_`grp')
}

	xtile c2_00=CQ8B, nq(`bins0')
	egen x2_00=mean(CQ8B) , by(c2_00)

forvalues grp=1(1)1 {
	sort  x2_`grp'
	by x2_`grp': gen _t2_`grp'=_n
}
	
	sort  x2_00
	by x2_00: gen _t2_00=_n
	

***~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*** 			capital
***~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
  
quiet forvalues grp=1(1)1 {
	xtile c3_`grp'=CQ8C [aw=_wgt] if treatmentN==`grp', nq(`bins0')
	egen x3_`grp'=mean(CQ8C) if treatmentN==`grp', by(c3_`grp')
	egen y3_`grp'=mean(w2_CQ8C) if  treatmentN==`grp', by(c3_`grp')
}

	xtile c3_00=CQ8C, nq(`bins0')
	egen x3_00=mean(CQ8C) , by(c3_00)

forvalues grp=1(1)1 {
	sort  x3_`grp'
	by x3_`grp': gen _t3_`grp'=_n
}
	
	sort  x3_00
	by x3_00: gen _t3_00=_n
	

***~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
*** 			wages
***~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
   
quiet forvalues grp=1(1)1 {
	xtile c4_`grp'=CQ8D [aw=_wgt] if treatmentN==`grp', nq(`bins0')
	egen x4_`grp'=mean(CQ8D) if treatmentN==`grp', by(c4_`grp')
	egen y4_`grp'=mean(w2_CQ8D) if  treatmentN==`grp', by(c4_`grp')
}

	xtile c4_00=CQ8D, nq(`bins0')
	egen x4_00=mean(CQ8D) , by(c4_00)

forvalues grp=1(1)1 {
	sort  x4_`grp'
	by x4_`grp': gen _t4_`grp'=_n
}
	
	sort  x4_00
	by x4_00: gen _t4_00=_n
	
			
	
twoway ///
		/// CONTROL GROUP
		(scatter y1_1 x1_1 if _t1_1==1, msymbol(th) mcolor(black) ) ///
		(lfit y1_1 x1_1 if _t1_1==1, lcolor(black)) ///
		/// TREATMENT GROUP 2
		(scatter y2_1 x2_1 if _t2_1==1, msymbol(sh) mcolor(red) ) ///
		(lfit y2_1 x2_1 if _t2_1==1, lcolor(red) lpattern(shortdash)) ///
		/// TREATMENT GROUP 3
		(scatter y3_1 x3_1 if _t3_1==1, msymbol(oh) mcolor(green) ) ///
		(lfit y3_1 x3_1 if _t3_1==1, lcolor(green) lpattern(longdash)) ///
		/// TREATMENT GROUP 4
		(scatter y4_1 x4_1 if _t4_1==1, msymbol(dh) mcolor(blue) ) ///
		(lfit y4_1 x4_1 if _t4_1==1, lcolor(blue) lpattern(dash)) ///		
		, ///
		legend(order(1 3 5 7) label(1 "Prices") label(3 "Employment") label(5 "Capital stock") label(7 "Wages") rows(4) ring(0) position(11) rowgap(0.2) ) ///
		xtitle("Plan") ///
		ytitle("Realization") ///
		graphregion(color(white)) bgcolor(white) ///
		xlabel(-1(1)11) ylabel(-1(1)10) ///
		name(AppendixFigure01, replace)
		